@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
 our $AUTHORITY = 'cpan:GENEHACK';
-$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.8';
+$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.9';
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -23,6 +23,7 @@ use Dist::Zilla::Plugin::PkgVersion;
 use Dist::Zilla::Plugin::TaskWeaver;
 use Dist::Zilla::Plugin::PodWeaver;
 use Dist::Zilla::Plugin::MetaConfig;
+use Dist::Zilla::Plugin::MetaResources;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::InstallGuide;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
@@ -95,6 +96,9 @@ sub configure {
     # include a bunch of dist::zilla meta info in META.* files
     'MetaConfig' ,
 
+    # support for setting repo metadata
+    'MetaResources',
+
     # include a META.json file in addition to META.yml
     'MetaJSON' ,
   );
@@ -164,7 +168,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
@@ -200,6 +204,8 @@ this:
 
     [MetaConfig]
 
+    [MetaResources]
+
     [MetaJSON]
 
     [InstallGuide]
